<?php
/**
 * @package Catch Themes
 * @subpackage Catch Box
 * @since Catch Box 1.4
 */


/**
 * Sanitizes Checkboxes
 * @param  $input entered value
 * @return sanitized output
 *
 * @since Catch Box 4.4
 */
function catchbox_sanitize_checkbox( $input ) {
	if ( "1" == $input ) {
		return "1";
	}
	else {
		return "0";
   	}
}


/**
 * Sanitizes Custom CSS
 * @param  $input entered value
 * @return sanitized output
 *
 * @since Catch Box 4.4
 */
function catchbox_sanitize_custom_css( $input ) {
	if ( $input != '' ) {
        $input = str_replace( '<=', '&lt;=', $input );

        $input = wp_kses_split( $input, array(), array() );

        $input = str_replace( '&gt;', '>', $input );

        $input = strip_tags( $input );

        return $input;
 	}
    else {
    	return '';
    }
}

/**
 * Image sanitization callback example.
 *
 * Checks the image's file extension and mime type against a whitelist. If they're allowed,
 * send back the filename, otherwise, return the setting default.
 *
 * - Sanitization: image file extension
 * - Control: text, WP_Customize_Image_Control
 *
 * @see wp_check_filetype() https://developer.wordpress.org/reference/functions/wp_check_filetype/
 *
 * @param string               $image   Image filename.
 * @param WP_Customize_Setting $setting Setting instance.
 * @return string The image filename if the extension is allowed; otherwise, the setting default.
 */
function catchbox_sanitize_image( $image, $setting ) {
	/*
	 * Array of valid image file types.
	 *
	 * The array includes image mime types that are included in wp_get_mime_types()
	 */
    $mimes = array(
        'jpg|jpeg|jpe' => 'image/jpeg',
        'gif'          => 'image/gif',
        'png'          => 'image/png',
        'bmp'          => 'image/bmp',
        'tif|tiff'     => 'image/tiff',
        'ico'          => 'image/x-icon'
    );
	// Return an array with file extension and mime_type.
    $file = wp_check_filetype( $image, $mimes );
	// If $image has a valid mime_type, return it; otherwise, return the default.
    return ( $file['ext'] ? $image : $setting->default );
}

/**
 * Sanitizes post_id in slider
 * @param  $input entered value
 * @return sanitized output
 *
 * @since Catch Box 4.4
 */
function catchbox_sanitize_post_id( $input ) {
	// Ensure $input is an absolute integer.
	$post_id = absint( $input );
	// If $page_id is an ID of a published page, return it; otherwise, return empty
	return ( 'publish' == get_post_status( $post_id ) ? $post_id : '' );
}

/**
 * Number Range sanitization callback example.
 *
 * - Sanitization: number_range
 * - Control: number, tel
 *
 * Sanitization callback for 'number' or 'tel' type text inputs. This callback sanitizes
 * `$number` as an absolute integer within a defined min-max range.
 *
 * @see absint() https://developer.wordpress.org/reference/functions/absint/
 *
 * @param int                  $number  Number to check within the numeric range defined by the setting.
 * @param WP_Customize_Setting $setting Setting instance.
 * @return int|string The number, if it is zero or greater and falls within the defined range; otherwise,
 *                    the setting default.
 */
function catchbox_sanitize_number_range( $number, $setting ) {

	// Ensure input is an absolute integer.
	$number = absint( $number );

	// Get the input attributes associated with the setting.
	$atts = $setting->manager->get_control( $setting->id )->input_attrs;

	// Get minimum number in the range.
	$min = ( isset( $atts['min'] ) ? $atts['min'] : $number );

	// Get maximum number in the range.
	$max = ( isset( $atts['max'] ) ? $atts['max'] : $number );

	// Get step.
	$step = ( isset( $atts['step'] ) ? $atts['step'] : 1 );

	// If the number is within the valid range, return it; otherwise, return the default
	return ( $min <= $number && $number <= $max && is_int( $number / $step ) ? $number : $setting->default );
}


/**
 * Select sanitization callback example.
 *
 * - Sanitization: select
 * - Control: select, radio
 *
 * Sanitization callback for 'select' and 'radio' type controls. This callback sanitizes `$input`
 * as a slug, and then validates `$input` against the choices defined for the control.
 *
 * @see sanitize_key()               https://developer.wordpress.org/reference/functions/sanitize_key/
 * @see $wp_customize->get_control() https://developer.wordpress.org/reference/classes/wp_customize_manager/get_control/
 *
 * @param string               $input   Slug to sanitize.
 * @param WP_Customize_Setting $setting Setting instance.
 * @return string Sanitized slug if it is a valid choice; otherwise, the setting default.
 */
function catchbox_sanitize_select( $input, $setting ) {
	// Get list of choices from the control associated with the setting.
	$choices = $setting->manager->get_control( $setting->id )->choices;

	// If the input is a valid key, return it; otherwise, return the default.
	return ( array_key_exists( $input, $choices ) ? $input : $setting->default );
}


/**
 * Reset all settings to default
 * @param  $input entered value
 * @return sanitized output
 *
 * @since Catch Box 4.4
 */
function catchbox_reset_all_settings( $input ) {
	if ( $input == 1 ) {
        // Delete all theme options
        delete_option('catchbox_options' );

        // Flush out all transients	on reset
        catchbox_themeoption_invalidate_caches();
    }
    else {
        return '';
    }
}

/**
 * Reset colors
 * @param  $input entered value
 * @return sanitized output
 *
 * @since Catch Box 4.4
 */
function catchbox_sanitize_reset_colors( $input ) {
	if ( $input == 1 ) {
        global $catchbox_options_settings, $catchbox_options_defaults;

        $options = $catchbox_options_settings;

		$defaults = $catchbox_options_defaults;

		$options[ 'color_scheme' ] = $defaults[ 'color_scheme' ];
		$options[ 'header_background' ] = $defaults[ 'header_background' ];
		$options[ 'slider_background' ] = $defaults[ 'slider_background' ];
		$options[ 'content_background' ] = $defaults[ 'content_background' ];
		$options[ 'article_background' ] = $defaults[ 'article_background' ];
		$options[ 'footer_background' ] = $defaults[ 'footer_background' ];
		$options[ 'footer_sidebar_background' ] = $defaults[ 'footer_sidebar_background' ];
		$options[ 'widget_background' ] = $defaults[ 'widget_background' ];
		$options[ 'title_hover_color' ] = $defaults[ 'title_hover_color' ];
		$options[ 'heading_color' ] = $defaults[ 'heading_color' ];
		$options[ 'heading_hover_color' ] = $defaults[ 'heading_hover_color' ];
		$options[ 'slider_text' ] = $defaults[ 'slider_text' ];
		$options[ 'meta_color' ] = $defaults[ 'meta_color' ];
		$options[ 'text_color' ] = $defaults[ 'text_color' ];
		$options[ 'link_color' ] = $defaults[ 'link_color' ];
		$options[ 'widget_heading_color' ] = $defaults[ 'widget_heading_color' ];
		$options[ 'widget_text_color' ] = $defaults[ 'widget_text_color' ];
		$options[ 'menu_background' ] = $defaults[ 'menu_background' ];
		$options[ 'menu_color' ] = $defaults[ 'menu_color' ];
		$options[ 'hover_background_color' ] = $defaults[ 'hover_background_color' ];
		$options[ 'hover_text_color' ] = $defaults[ 'hover_text_color' ];
		$options[ 'active_background_color' ] = $defaults[ 'active_background_color' ];
		$options[ 'active_text_color' ] = $defaults[ 'active_text_color' ];
		$options[ 'sub_menu_bg_color' ] = $defaults[ 'sub_menu_bg_color' ];
		$options[ 'sub_menu_text_color' ] = $defaults[ 'sub_menu_text_color' ];
		$options[ 'scrollup_bg_color' ] = $defaults[ 'scrollup_bg_color' ];
		$options[ 'scrollup_text_color' ] = $defaults[ 'scrollup_text_color' ];

		update_option( 'catchbox_options', $options );
    }
}

/**
 * Reset Layout
 * @param  $input entered value
 * @return sanitized output
 *
 * @since Catch Box 4.4
 */
function catchbox_sanitize_reset_layout( $input ) {
	if ( $input == 1 ) {
        global $catchbox_options_settings, $catchbox_options_defaults;

        $options = $catchbox_options_settings;

		$defaults = $catchbox_options_defaults;

		$options[ 'sidebar_layout' ] = $defaults[ 'sidebar_layout' ];

		update_option( 'catchbox_options', $options );
    }
}

/**
 * Reset Fonts
 * @param  $input entered value
 * @return sanitized output
 *
 * @since Catch Box 4.4
 */
function catchbox_sanitize_reset_typography( $input ) {
	if ( $input == 1 ) {
        global $catchbox_options_settings, $catchbox_options_defaults;

        $options = $catchbox_options_settings;

		$defaults = $catchbox_options_defaults;

		$options['body_font'] = $defaults[ 'body_font' ];
		$options['title_font'] = $defaults[ 'title_font' ];
		$options['headings_font'] = $defaults[ 'headings_font' ];
		$options['content_font'] = $defaults[ 'content_font' ];

		update_option( 'catchbox_options', $options );
    }
}

/**
 * Reset Fonts size
 * @param  $input entered value
 * @return sanitized output
 *
 * @since Catch Box 4.4
 */
function catchbox_sanitize_reset_typography_font_size( $input ) {
	if ( $input == 1 ) {
        global $catchbox_options_settings, $catchbox_options_defaults;

        $options = $catchbox_options_settings;

		$defaults = $catchbox_options_defaults;

		$options['body_font_size'] = $defaults[ 'body_font_size' ];
		$options['body_font_size_unit'] = $defaults[ 'body_font_size_unit' ];
		$options['body_line_height'] = $defaults[ 'body_line_height' ];
		$options['body_line_height_unit'] = $defaults[ 'body_line_height_unit' ];
		$options['site_title_font_size'] = $defaults[ 'site_title_font_size' ];
		$options['site_title_font_size_unit'] = $defaults[ 'site_title_font_size_unit' ];
		$options['site_title_line_height'] = $defaults[ 'site_title_line_height' ];
		$options['site_title_line_height_unit'] = $defaults[ 'site_title_line_height_unit' ];
		$options['site_description_font_size'] = $defaults[ 'site_description_font_size' ];
		$options['site_description_font_size_unit'] = $defaults[ 'site_description_font_size_unit' ];
		$options['site_description_line_height'] = $defaults[ 'site_description_line_height' ];
		$options['site_description_line_height_unit'] = $defaults[ 'site_description_line_height_unit' ];
		$options['h1_font_size'] = $defaults[ 'h1_font_size' ];
		$options['h1_font_size_unit'] = $defaults[ 'h1_font_size_unit' ];
		$options['h2_font_size'] = $defaults[ 'h2_font_size' ];
		$options['h2_font_size_unit'] = $defaults[ 'h2_font_size_unit' ];
		$options['h3_font_size'] = $defaults[ 'h3_font_size' ];
		$options['h3_font_size_unit'] = $defaults[ 'h3_font_size_unit' ];
		$options['h4_font_size'] = $defaults[ 'h4_font_size' ];
		$options['h4_font_size_unit'] = $defaults[ 'h4_font_size_unit' ];
		$options['headings_line_height'] = $defaults[ 'headings_line_height' ];
		$options['headings_line_height_unit'] = $defaults[ 'headings_line_height_unit' ];
		$options['content_font_size'] = $defaults[ 'content_font_size' ];
		$options['content_font_size_unit'] = $defaults[ 'content_font_size_unit' ];
		$options['content_line_height'] = $defaults[ 'content_line_height' ];
		$options['content_line_height_unit'] = $defaults[ 'content_line_height_unit' ];

		update_option( 'catchbox_options', $options );
    }
}

/**
 * Reset Footer
 * @param  $input entered value
 * @return sanitized output
 *
 * @since Catch Box 4.4
 */
function catchbox_sanitize_reset_footer( $input ) {
	if ( $input == 1 ) {
        global $catchbox_options_settings, $catchbox_options_defaults;

        $options = $catchbox_options_settings;

		$defaults = $catchbox_options_defaults;

		$options[ 'footer_code' ] = $defaults[ 'footer_code' ];

		update_option( 'catchbox_options', $options );
	}
}

/**
 * Reset Footer
 * @param  $input entered value
 * @return sanitized output
 *
 * @since Catch Box 4.4
 */
function catchbox_sanitize_reset_header_space( $input ) {
	if ( $input == 1 ) {
        global $catchbox_options_settings, $catchbox_options_defaults;

        $options = $catchbox_options_settings;

		$defaults = $catchbox_options_defaults;

		$options['header_top_size'] 		= $defaults[ 'header_top_size' ];
		$options['header_top_size_unit'] 	= $defaults[ 'header_top_size_unit' ];
		$options['header_right_size'] 		= $defaults[ 'header_right_size' ];
		$options['header_right_size_unit'] 	= $defaults[ 'header_right_size_unit' ];
		$options['header_bottom_size'] 		= $defaults[ 'header_bottom_size' ];
		$options['header_bottom_size_unit'] = $defaults[ 'header_bottom_size_unit' ];
		$options['header_left_size'] 		= $defaults[ 'header_left_size' ];
		$options['header_left_size_unit'] 	= $defaults[ 'header_left_size_unit' ];

		update_option( 'catchbox_options', $options );
	}
}


/**
 * Dummy Sanitizaition function as it contains no value to be sanitized
 *
 * @since Catch Box 4.4
 */
function catchbox_sanitize_important_link() {
	return false;
}

/**
 * Sanitize Footer Code
 * @param  $input entered value
 * @return sanitized value
 *
 * @since Catch Box 4.4
 */
function catchbox_sanitize_footer_code( $input ) {
	return stripslashes( wp_filter_post_kses( addslashes ( $input ) ) );
}

/**
 * Sanitizes category list in slider
 * @param  $input entered value
 * @return sanitized output
 *
 * @since Catch Box 4.4
 */
function catchbox_sanitize_category_list( $input ) {
	if ( $input != '' ) {
		$args = array(
						'type'			=> 'post',
						'child_of'      => 0,
						'parent'        => '',
						'orderby'       => 'name',
						'order'         => 'ASC',
						'hide_empty'    => 0,
						'hierarchical'  => 0,
						'taxonomy'      => 'category',
					);

		$categories = ( get_categories( $args ) );

		$category_list 	=	array();

		foreach ( $categories as $category )
			$category_list 	=	array_merge( $category_list, array( $category->term_id ) );

		if ( count( array_intersect( $input, $category_list ) ) == count( $input ) ) {
	    	return $input;
	    }
	    else {
    		return '';
   		}
    }
    else {
    	return '';
    }
}